==> tlf-0.9.19.tar.gz: tlf-0.9.19/src/searchcallarray.c <==
/*
 * Tlf - contest logging program for amateur radio operators
 * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
	/* ------------------------------------------------------------
 	*      search  call array
 	*
 	*--------------------------------------------------------------*/

 	#include "searchcallarray.h"
 	
 	int searchcallarray  (char  *hiscall)
 	{
 	extern char hiscall[];
 	extern int callarray_nr;
 	extern char callarray[MAX_CALLS][20];
 	
 	int found = 0;
 	int i;
	static char cbuffer[40] = "";
 	
 		
 		cbuffer[0] = '\0';
 		strcat(cbuffer,  hiscall);
 		strcat(cbuffer, "           ");
 		cbuffer[10] = '\0';
 	 	 	
 	 	for (i = 0 ; i  <= callarray_nr ; i++){
 	 	 	
 	 		if (strcmp(callarray[i], cbuffer) == 0){
 	 			found = i;
 	 			break;
 	 		}
 	 		
 	 	 }
 	
 	     return (found);
 	}

==> tlf_0.9.32.3.orig.tar.gz: tlf-0.9.32.3/src/searchcallarray.c <==
/*
 * Tlf - contest logging program for amateur radio operators
 * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
	/* ------------------------------------------------------------
 	*      search  call array
 	*
 	*--------------------------------------------------------------*/

 	#include "searchcallarray.h"
 	
 	int searchcallarray  (char  *hiscall)
 	{
// 	extern char hiscall[];
 	extern int callarray_nr;
 	extern char callarray[MAX_CALLS][20];
 	
 	int found = 0;
 	int i;
	static char cbuffer[40] = "";
 	
 		
 		cbuffer[0] = '\0';
 		strcat(cbuffer,  hiscall);
 		strcat(cbuffer, "           ");
 		cbuffer[10] = '\0';
 	 	 	
 	 	for (i = 0 ; i  <= callarray_nr ; i++){
 	 	 	
 	 		if (strcmp(callarray[i], cbuffer) == 0){
 	 			found = i;
 	 			break;
 	 		}
 	 		
 	 	 }
 	
 	     return (found);
 	}
